/*
 * Copyright 2010 Trustees of the University of Pennsylvania Licensed under the
 * Educational Community License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License. You may
 * obtain a copy of the License at
 *
 * http://www.osedu.org/licenses/ECL-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an "AS IS"
 * BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package metridoc.plugins

import java.lang.annotation.Target
import java.lang.annotation.Retention
import java.lang.annotation.Documented
import java.lang.annotation.ElementType
import java.lang.annotation.RetentionPolicy
import metridoc.utils.ObjectUtils
/**
 * Created by IntelliJ IDEA.
 * User: tbarker
 * Date: 9/3/11
 * Time: 2:33 PM
 */
@Target(ElementType.TYPE)
@Retention(RetentionPolicy.RUNTIME)
@Documented
public @interface Plugin {
    /**
     * specifies the type of the plugin.  For instance 'job'.  Basically allows metridoc to have multipl extension
     * points
     * @return the type of plugin
     */
    String value()
    /**
     * a space separated list of parameters, such as 'foo=bar bar=baz'.  This is not necessarily required, depends on
     * the type of plugin
     * @return parameters for the plugin
     */
    String properties() default ""
    /**
     * defines the class type that the plugin is meant to be applied to
     */
    Class applyTo() default ObjectUtils.Null
}